@@ -244,7 +244,7 @@ colnames(mat) <- make.names(seq_len(ncol(mat)))
 
 wb <- wb_workbook() %>%
   wb_add_worksheet("test") %>%
-  wb_add_data(x = mat, dims = wb_dims(from_row = 2, from_col = 2)) %>%
+  wb_add_data(x = mat, dims = wb_dims(from_dims = "B2")) %>%
   # center first row
   wb_add_cell_style(dims = "B2:C2", horizontal = "center") %>%
   # add border for first row
